@@ -124,12 +124,12 @@ static const char USAGE_MESSAGE[] =
 "  -F, --max-frag=N             max fragment size in base pairs\n"
 "\n"
 "  Note 1: --max-branches was not effective for truncating expensive searches,\n"
-"  and has been superceded by the --max-cost option.\n"
+"  and has been superseded by the --max-cost option.\n"
 "\n"
 "  Note 2: --max-frag was formerly used to determine the maximum gap\n"
 "  size that abyss-sealer would attempt to close, according to the formula\n"
 "  max_gap_size = max_frag - 2 * flank_length, where flank_length is\n"
-"  determined by the -L option.  --max-frag is superceded by the more\n"
+"  determined by the -L option.  --max-frag is superseded by the more\n"
 "  intuitive -G (--max-gap-length) option. The related option --min-frag\n"
 "  does not seem to have any practical use.\n"
 "\n"
